raw_iipsc: Raw item responses on real circumplex scales

raw_iipscR Documentation

Raw item responses on real circumplex scales

Description

A small example dataset containing raw item responses on the Inventory of Interpersonal Problems, Short Circumplex (IIP-SC). This data set is useful for testing functions that operate on item-level data.

Usage

raw_iipsc

Format

A data frame with 10 observations and 32 variables.


circumplex documentation built on May 25, 2026, 1:06 a.m.