Learn R Programming

circumplex (version 2.0.1)

theme_circumplex: Circumplex canvas theme

Description

The ggplot2 theme applied to the circumplex canvas built by ggcircumplex(). It is built on ggplot2::theme_minimal() so that the amplitude rings, displacement spokes, and labels drawn by coord_circumplex() are themed panel furniture that respond to further theming. Apply it to a custom circumplex plot, and add + theme_*() or + theme() on top to restyle the canvas.

Usage

theme_circumplex(base_size = 12)

Value

A ggplot2 theme object, to be added to a plot with +.

Arguments

base_size

A single positive number giving the base font size (in pt) for the theme (default = 12).

See Also

Other circumplex layers: coord_circumplex(), geom_ssm_arc(), geom_ssm_path(), geom_ssm_point(), ggcircumplex(), scale_x_circumplex()

Examples

Run this code
# Restyle the canvas with a larger base font
ggcircumplex(octants()) + theme_circumplex(base_size = 16)

Run the code above in your browser using DataLab